@@ -19,7 +19,6 @@
 
 
 import os
-import tarfile
 import tempfile
 import shutil
 
@@ -34,6 +33,8 @@ from samba.samba3 import libsmb_samba_internal as libsmb
 from samba.logger import get_samba_logger
 from samba import NTSTATUSError
 from samba.auth_util import system_session_unix
+from samba import safe_tarfile as tarfile
+
 
 # don't include volumes
 SMB_FILE_ATTRIBUTE_FLAGS = libsmb.FILE_ATTRIBUTE_SYSTEM | \
@@ -52,7 +53,7 @@ class XattrBackendError(Exception):
 
 
 def checkset_backend(lp, backend, eadbfile):
-    '''return the path to the eadb, or None'''
+    """return the path to the eadb, or None"""
     if backend is None:
         xattr_tdb = lp.get("xattr_tdb:file")
         if xattr_tdb is not None:
@@ -496,9 +497,9 @@ def backup_online(smb_conn, dest_tarfile_path, dom_sid):
 
     1. Create a temp dir as container dir
     2. Backup all files with dir structure into container dir
-    3. Generate file.NTACL files for each file and dir in contianer dir
+    3. Generate file.NTACL files for each file and dir in container dir
     4. Create a tar file from container dir(without top level folder)
-    5. Delete contianer dir
+    5. Delete container dir
     """
 
     logger = get_samba_logger()
@@ -537,7 +538,7 @@ def backup_online(smb_conn, dest_tarfile_path, dom_sid):
                 ntacl_sddl_str = smb_helper.get_acl(r_name, as_sddl=True)
                 _create_ntacl_file(l_name, ntacl_sddl_str)
             except NTSTATUSError as e:
-                logger.error('Failed to get the ntacl for %s: %s' % \
+                logger.error('Failed to get the ntacl for %s: %s' %
                              (r_name, e.args[1]))
                 logger.warning('The permissions for %s may not be' % r_name +
                                ' restored correctly')
