@@ -31,7 +31,7 @@ class GroupCmdTestCase(SambaToolCmdTest):
     samdb = None
 
     def setUp(self):
-        super(GroupCmdTestCase, self).setUp()
+        super().setUp()
         self.samdb = self.getSamDB("-H", "ldap://%s" % os.environ["DC_SERVER"],
                                    "-U%s%%%s" % (os.environ["DC_USERNAME"], os.environ["DC_PASSWORD"]))
         self.groups = []
@@ -74,7 +74,7 @@ class GroupCmdTestCase(SambaToolCmdTest):
             self.assertEqual("%s" % found.get("description"), group["description"])
 
     def tearDown(self):
-        super(GroupCmdTestCase, self).tearDown()
+        super().tearDown()
         # clean up all the left over groups, just in case
         for group in self.groups:
             if self._find_group(group["name"]):
@@ -332,7 +332,7 @@ class GroupCmdTestCase(SambaToolCmdTest):
 
         for groupobj in grouplist:
             name = str(groupobj.get("dn", idx=0))
-            found = self.assertMatch(out, name, "group '%s' not found" % name)
+            self.assertMatch(out, name, "group '%s' not found" % name)
 
 
     def test_move(self):
@@ -575,10 +575,10 @@ template """
                         "Total groups not reported correctly")
 
     def _random_user(self, base=None):
-        '''
+        """
         create a user with random attribute values, you can specify
         base attributes
-        '''
+        """
         if base is None:
             base = {}
         user = {
